package app.navigation;

import com.vaadin.flow.router.WildcardParameter;
import org.springframework.lang.NonNull;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;

@SuppressWarnings("OptionalUsedAsFieldOrParameterType")
class NavigationUtils {

    private NavigationUtils() {
    }

    @NonNull
    static Map<NavigationLevel, Optional<String>> getParameterMap(@WildcardParameter String param) {
        Map<NavigationLevel, Optional<String>> map = new HashMap<>();
        String[] params = param.split("/");
        switch (params.length) {
            case 3:
                map.put(NavigationLevel.MATCH, Optional.of(params[2]));
            case 2:
                map.put(NavigationLevel.MATCHDAY, Optional.of(params[1]));
            case 1:
                map.put(NavigationLevel.SEASON, Optional.of(params[0]));
            default:
                break;
        }
        map.putIfAbsent(NavigationLevel.MATCH, Optional.empty());
        map.putIfAbsent(NavigationLevel.MATCHDAY, Optional.empty());
        map.putIfAbsent(NavigationLevel.SEASON, Optional.empty());
        return map;
    }

    @NonNull
    static String getWildcardParam(String... params) {
        StringBuilder stringBuilder = new StringBuilder();
        for (String param : params) {
            if (param == null || param.equals("")) {
                break;
            }
            stringBuilder.append(param).append("/");
        }
        return stringBuilder.toString();
    }

    static <T> Optional<T> getObjectFromParam(List<T> objectList, Optional<String> param) {
        if (param.isEmpty()) {
            return Optional.empty();
        }
        return objectList.stream()
                .filter(match -> match.toString().equals(param.get()))
                .findFirst();
    }
}
