package app.views.match.components;

import app.data.entity.Game;
import app.views.match.components.utils.GameComponentUtils;
import com.vaadin.flow.component.button.Button;
import com.vaadin.flow.component.html.Div;
import com.vaadin.flow.component.html.Image;
import com.vaadin.flow.component.html.Label;
import com.vaadin.flow.component.orderedlayout.FlexComponent;
import com.vaadin.flow.component.orderedlayout.HorizontalLayout;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;

public class GameComponent extends Div {

    private final Game game;

    private final HorizontalLayout inner = new HorizontalLayout();

    private final VerticalLayout left = new VerticalLayout();
    private final Div right = new Div();

    public GameComponent(Game game) {
        this.game = game;

        addClassName("wrapper");
        addClassName("game-card");

        configureInner();
    }

    private void configureInner() {
        add(inner);
        inner.add(left, right);
        inner.setAlignItems(FlexComponent.Alignment.CENTER);

        configureLeft();
        configureRight();
    }

    private void configureLeft() {
        Label header = GameComponentUtils.getHeader(game);
        Div timeControlDiv = GameComponentUtils.getTimeControlDiv(game);
        Div blackDiv = GameComponentUtils.getPlayerDiv(game, false);
        Label vsLabel = GameComponentUtils.getVsLabel();
        Div whiteDiv = GameComponentUtils.getPlayerDiv(game, true);
        Button button = GameComponentUtils.getChessComButton(game);

        left.add(header, timeControlDiv, blackDiv, vsLabel, whiteDiv, button);
        left.addClassName("game-info-div");
        left.setAlignItems(FlexComponent.Alignment.CENTER);

        left.setHeightFull();

    }

    private void configureRight() {
        right.addClassName("game-image-div");

        Image image = new Image(GameComponentUtils.getImagePath(game), "Could not find game image.");
        right.add(image);
        image.setWidthFull();
        image.setHeightFull();
    }
}
