package app.views.match.components;

import app.data.bean.CalculatedMatch;
import app.data.entity.Game;
import app.data.entity.Match;
import app.navigation.Navigation;
import app.utils.EntityComponentUtils;
import app.utils.StringUtils;
import app.views.navigation.interfaces.ContentConfigurable;
import com.vaadin.flow.component.html.Div;
import com.vaadin.flow.component.html.Label;
import com.vaadin.flow.component.orderedlayout.FlexComponent;
import com.vaadin.flow.component.orderedlayout.FlexLayout;
import com.vaadin.flow.component.orderedlayout.HorizontalLayout;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;

import java.util.NoSuchElementException;

public class MatchComponent extends Div implements ContentConfigurable {

    private final Navigation navigation;

    private final VerticalLayout headerLayout = new VerticalLayout();
    private final HorizontalLayout headerPlayersLayout = new HorizontalLayout();
    private final Label headerResultLabel = new Label();

    private final FlexLayout gamesLayout = new FlexLayout();

    public MatchComponent(Navigation navigation) {
        this.navigation = navigation;

        add(headerLayout, gamesLayout);

        configureHeaderLayout();
        configureGamesLayout();
    }

    private void configureHeaderLayout() {
        headerLayout.add(headerPlayersLayout, headerResultLabel);

        headerPlayersLayout.addClassName("match-header-players");

        headerResultLabel.addClassName("match-header-result");
        headerResultLabel.addClassName("bold-header");
    }

    private void configureGamesLayout() {
        gamesLayout.setFlexWrap(FlexLayout.FlexWrap.WRAP);
        gamesLayout.setJustifyContentMode(FlexComponent.JustifyContentMode.CENTER);
    }

    @Override
    public void configureContent() {
        try {
            Match match = navigation.getSelectedMatch().orElseThrow();

            configureHeaderContent(match);

            gamesLayout.removeAll();
            for (Game game : match.getGames()) {
                gamesLayout.add(new GameComponent(game));
            }
        } catch (NoSuchElementException e) {
            gamesLayout.removeAll();
            add(navigation.getValidationLabel());
        }
    }

    private void configureHeaderContent(Match match) {
        CalculatedMatch calculatedMatch = navigation.getMatchService().getCalculatedMatch(match);

        HorizontalLayout player1 = EntityComponentUtils.getPlayerLabel(calculatedMatch.getPlayer1());
        HorizontalLayout player2 = EntityComponentUtils.getPlayerLabel(calculatedMatch.getPlayer2());
        Label vs = new Label("vs.");

        headerPlayersLayout.removeAll();
        headerPlayersLayout.add(player1, vs, player2);

        headerResultLabel.setText(String.format("%s",
                StringUtils.getResultString("-", calculatedMatch.getScore1(), calculatedMatch.getScore2())));
    }
}
